# PhysicX library for python
  
This project with LICENSE GNU-GPLv3, in fact created for developers , physicist , mathematicians and this project
<pre>pre-released</pre>
github:https://github.com/anonymous14725/physicX <br/>
pypi:https://pypi.org/project/physicX
